Contributors to Askbot Project — Askbot v0.7.43 documentation

# Askbot Project Documentation

Home | Ask Questions | Hire Us | Documentation | Contribute | Contact

# Contributors to Askbot Project

This is the list of contributors to the code of Askbot project. The list is probably incomplete, apologies for any omissions. Thanks for all your help

## Programming and documentation

- Mike Chen & Sailing Cai - original authors of CNPROG forum
- Evgeny Fadeev - founder of askbot
- Adolfo Fitoria
- Tomasz Zielinski
- Sayan Chowdhury
- Andy Knotts
- Benoit Lavine (with Windriver Software, Inc.)
- Jeff Madynski
- Jishnu
- Hrishi
- Andrei Mamoutkine
- Daniel Mican
- Dejan Noveski
- Vasil Vangelovski
- Ramiro Morales (with Machinalis)
- Vladimir Bokov
- NoahY
- Gael Pasgrimaud (bearstech)
- Arun SAG
- Rag Sagar
- Alex Robbins
- Tomasz Szynalski
- Raghu Udiyar
- Alexander Werner
- Rosandra Cuello Suñol
- hjwp
- Jacob Oscarson
- Radim Řehůřek
- monkut
- Jim Tittsler
- Silvio Heuberger

## Translations

- Mike Chen, Sailing Cai, suyu8776 - Chinese
- Bruno Sarlo, Adolfo Fitoria, Francisco Espinoza - Spanish
- Evgeny Kalinin - Russian
- Evgeny Fadeev - English
- Oktay Yildiz, Onur Mat, Cemre - Turkish
- Jérôme Blondon (bearstech) - French
- Pekka Gaiser - German
- Pekka Järvinen - Finnish
- Adi Robian - Romanian
- Dario Ghilardi, Federico Poloni, Luca Ferroni - Italian
- Jordi Bofill - Catalan